@@ -12,8 +12,13 @@ from helix_catalog_sdk.repo import BaseRepo
 
 
 class Catalog:
-    def __init__(self, repo: BaseRepo):
+    def __init__(
+        self,
+        repo: BaseRepo,
+        environment: HelixEnvironment = HelixEnvironment.PRODUCTION,
+    ):
         self._repo = repo
+        self.environment = environment
         self._last_updated_data_source_dttm: datetime = datetime.utcnow() + timedelta(
             days=-1
         )
@@ -63,9 +68,7 @@ class Catalog:
                 if self._repo.is_dir(file_path):
                     catalog_contents.extend(self._repo.list_items(file_path))
                 elif file_path.endswith(".json"):
-                    data_source = self.get_data_source(
-                        file_path, HelixEnvironment.PRODUCTION
-                    )
+                    data_source = self.get_data_source(file_path, self.environment)
                     if data_source:
                         data_sources.append((file_path, data_source))
             self._all_data_sources = data_sources
