@@ -127,10 +127,14 @@ class DataSource:
 
 class PipelineSubscription:
     def __init__(self, content: SimpleNamespace):
-        self.flow_name = content.flow_name
-        self.flow_parameters: List[str] = []
-        if hasattr(content, "flow_parameters"):
-            self.flow_parameters = content.flow_parameters
+        if isinstance(content, str):
+            self.flow_name: str = content
+            self.flow_parameters: List[str] = []
+        else:
+            self.flow_name = content.flow_name
+            self.flow_parameters = []
+            if hasattr(content, "flow_parameters"):
+                self.flow_parameters = content.flow_parameters
 
     @property
     def json_dict(self) -> Dict[str, Any]:
