@@ -62,12 +62,16 @@ def test_catalog_get_data_source() -> None:
         == "s3://prod-ingestion/raw/gencon/icd/Things/ThingFeed_06092021.json"
     )
 
-    assert len(data_source.pipeline_subscriptions) == 2
+    assert len(data_source.pipeline_subscriptions) == 3
     pipeline_subscription = data_source.pipeline_subscriptions[0]
+    assert pipeline_subscription.flow_name == "Simple subscription"
+    assert pipeline_subscription.flow_parameters == []
+
+    pipeline_subscription = data_source.pipeline_subscriptions[1]
     assert pipeline_subscription.flow_name == "INGEN Data Ingestion"
     assert pipeline_subscription.flow_parameters == ["people", "places"]
 
-    pipeline_subscription = data_source.pipeline_subscriptions[1]
+    pipeline_subscription = data_source.pipeline_subscriptions[2]
     assert pipeline_subscription.flow_name == "Test Flow"
     assert len(pipeline_subscription.flow_parameters) == 0
     assert pipeline_subscription.flow_parameters == []
@@ -114,12 +118,16 @@ def test_catalog_update_data_source_resource() -> None:
         == "s3://prod-ingestion/raw/gencon/icd/Things/ThingFeed_06092021.json"
     )
 
-    assert len(updated_data_source.pipeline_subscriptions) == 2
+    assert len(updated_data_source.pipeline_subscriptions) == 3
     pipeline_subscription = updated_data_source.pipeline_subscriptions[0]
+    assert pipeline_subscription.flow_name == "Simple subscription"
+    assert pipeline_subscription.flow_parameters == []
+
+    pipeline_subscription = updated_data_source.pipeline_subscriptions[1]
     assert pipeline_subscription.flow_name == "INGEN Data Ingestion"
     assert pipeline_subscription.flow_parameters == ["people", "places"]
 
-    pipeline_subscription = updated_data_source.pipeline_subscriptions[1]
+    pipeline_subscription = updated_data_source.pipeline_subscriptions[2]
     assert pipeline_subscription.flow_name == "Test Flow"
     assert len(pipeline_subscription.flow_parameters) == 0
     assert pipeline_subscription.flow_parameters == []
